@@ -23,17 +23,18 @@ class Reactor(object):
         'auth_username': None,
         'config': 'config.json',
         'critical_handlers': ['log', 'smtp'],
-        'format': 'short',
         'debug': False,
+        'format': 'short',
         'graphite_url': 'http://localhost',
+        'history_size': '1day',
         'interval': '10minute',
-        'history_size': 60,
-        'repeat_interval': '2hour',
         'logging': 'info',
         'method': 'average',
         'normal_handlers': ['log', 'smtp'],
         'pidfile': None,
         'prefix': '[BEACON]',
+        'repeat_interval': '2hour',
+        'request_timeout': 20.0,
         'send_initial': False,
         'warning_handlers': ['log', 'smtp'],
     }
